
# Slot: was informed by




URI: [core:was_informed_by](https://w3id.org/linkml/tests/core/was_informed_by)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Activity](Activity.md)

## Parents


## Children


## Used by

 * [Activity](Activity.md)
 * [Agent](Agent.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | prov:wasInformedBy |

